# flappybird

Flappy bird, but every sprite is its own window.

![Demo](https://raw.githubusercontent.com/tusharsadhwani/flappybird/main/demo.png)

Idea pretty much copied from [this Code Bullet video][video].

## Installation

```bash
pip install flappybird
```

or, run directly with `pipx`:

```bash
pipx run flappybird
```

## Usage

Start the game:

```bash
flappybird
```

[video]: https://www.youtube.com/watch?v=sWZJ6kRNw4g
